<?php

namespace FiloBlu\Popup\Setup;

use Magento\Framework\Setup\UpgradeSchemaInterface;
use Magento\Framework\Setup\SchemaSetupInterface;
use Magento\Framework\Setup\ModuleContextInterface;

class UpgradeSchema implements UpgradeSchemaInterface
{

    public function upgrade(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $setup->startSetup();

        //handle all possible upgrade versions

        if (!$context->getVersion()) {
            //no previous version found, installation, InstallSchema was just executed
            //be careful, since everything below is true for installation !
        }

        if (version_compare($context->getVersion(), '1.0.3') < 0)
        {

            //code to upgrade to 1.0.3
            // Get module table
            $tableName = $setup->getTable('filoblu_popup');

            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true)
            {
                // Declare data
                $columns = [
                   'enabled' => [
                       'type' => \Magento\Framework\DB\Ddl\Table::TYPE_BOOLEAN,
                       'nullable' => false,
                       'comment' => 'enabled'
                   ],

                   'link' => [
                       'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                       'length' => 150,
                       'nullable' => false,
                       'comment' => 'link'
                   ],

                   'store_ids' => [
                       'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                       'length' => 100,
                       'nullable' => false,
                       'comment' => 'store_ids'
                   ],

                   'cookie_duration' => [
                       'type' => \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                       'nullable' =>false,
                       'comment' => 'cookie_duration'
                   ],
               ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition)
                {
                    $connection->addColumn($tableName, $name, $definition);
                }
            }
        }


        if (version_compare($context->getVersion(), '1.0.4') < 0)
        {

            //code to upgrade to 1.0.4
            // Get module table
            $tableName = $setup->getTable('filoblu_popup');

            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true)
            {
                // Declare data
                $columns = [
                    'delay' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        'nullable' =>false,
                        'comment' => 'delay'
                    ],

               ];
                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition)
                {
                    $connection->addColumn($tableName, $name, $definition);
                }
            }
        }


        if (version_compare($context->getVersion(), '1.0.5') < 0)
        {
            //code to upgrade to 1.0.5
            // Get module table
            $tableName = $setup->getTable('filoblu_popup');
            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true)
            {
                // Declare data
                $columns = [
                    'link_text' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        'length' => 100,
                        'nullable' =>true,
                        'comment' => 'link_text'
                    ],

               ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition)
                {
                    $connection->addColumn($tableName, $name, $definition);
                }
            }
        }


        if (version_compare($context->getVersion(), '1.0.6') < 0)
        {

            //code to upgrade to 1.0.6
            // Get module table
            $tableName = $setup->getTable('filoblu_popup');
            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true)
            {
                // Declare data
                $columns = [
                    'css_style' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        'nullable' =>true,
                        'comment' => 'css_style'
                    ],

               ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition)
                {
                    $connection->addColumn($tableName, $name, $definition);
                }
            }
        }


        if (version_compare($context->getVersion(), '1.0.7') < 0)
        {

            //code to upgrade to 1.0.7
            // Get module table
            $tableName = $setup->getTable('filoblu_popup');
            // Check if the table already exists
            if ($setup->getConnection()->isTableExists($tableName) == true)
            {
                // Declare data
                $columns = [
                    'link_image' => [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        'nullable' =>true,
                        'comment' => 'link_image'
                    ],

               ];

                $connection = $setup->getConnection();
                foreach ($columns as $name => $definition)
                {
                    $connection->addColumn($tableName, $name, $definition);
                }
            }
        }

      }
  }
